Fabber plugin for Quantiphyse
=============================

Quantiphyse is a visualisation and data analysis tool for volumetric
medical imaging data especially MRI. See https://quantiphyse.org for more
information.

Fabber is a model fitting tool designed to fit nonlinear parameterised 
models to 4D fMRI data such as ASL, CEST, DCE, DSC, etc.

To install, either use the setup script or:

    pip install quantiphyse-fabber

The plugin will then be available from within Quantiphyse
